@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "sphinx-mode" "1.0.0"
+(define-package "sphinx-mode" "20250511.2023"
   "Minor mode providing sphinx support."
-  '((f    "0.20.0")
-    (dash "2.14.1"))
+  '((dash "2.14.1")
+    (f    "0.20"))
   :url "https://github.com/Fuco1/sphinx-mode"
-  :commit "9d4075c106fc837006394c4c803281383f2ec6f3"
-  :revdesc "9d4075c106fc"
+  :commit "038a9195b00636d38aa2fc3cf6cbff5cf84e0561"
+  :revdesc "038a9195b006"
   :keywords '("languages")
   :authors '(("Matúš Goljer" . "matus.goljer@gmail.com"))
   :maintainers '(("Matúš Goljer" . "matus.goljer@gmail.com")))
